// 登录接口
import {
	axios
} from '../utils/http.js'

const Certificate = {
	CertiList: 'Certificate/List',
	CertiAdd: 'Certificate/Add',
	CertiEdit: 'Certificate/Edit',

	CertiDel: 'Certificate/Del',
	Certi_pdf: 'Certificate/Pdf_List',
	Certi_pdfAdd: 'Certificate/Pdf_Add',//添加证书
	Certi_pdfUp: 'Certificate/Pdf_Up',//添加证书
	Certi_pdfDel: 'Certificate/Pdf_Del',//添加证书
	
}
export function CertiEdit(data) {
	return axios({
		url: Certificate.CertiEdit,
		method: 'post',
		data:data
	})
}
export function Certi_pdfDel(data) {
	return axios({
		url: Certificate.Certi_pdfDel,
		method: 'post',
		data:data
	})
}
export function Certi_pdfUp(data) {
	return axios({
		url: Certificate.Certi_pdfUp,
		method: 'post',
		data:data
	})
}
export function Certi_pdfAdd(data) {
	return axios({
		url: Certificate.Certi_pdfAdd,
		method: 'post',
		data:data
	})
}
export function Certi_pdf(data) {
	return axios({
		url: Certificate.Certi_pdf,
		method: 'post',
		data:data
	})
}
export function CertiDel(data) {
	return axios({
		url: Certificate.CertiDel,
		method: 'post',
		data:data
	})
}
export function CertiAdd(data) {
	return axios({
		url: Certificate.CertiAdd,
		method: 'post',
		data:data
	})
}
export function CertiList(data) {
	return axios({
		url: Certificate.CertiList,
		method: 'post',
		data:data
	})
}